@@ -11,7 +11,7 @@ import backoff as backoff_module
 from singer.catalog import Catalog
 
 DATETIME_PARSE = "%Y-%m-%dT%H:%M:%SZ"
-DATETIME_FMT = "%04Y-%m-%dT%H:%M:%S.%fZ"
+DATETIME_FMT = "%Y-%m-%dT%H:%M:%S.%fZ"
 
 def now():
     return datetime.datetime.utcnow().replace(tzinfo=pytz.UTC)
@@ -29,10 +29,10 @@ def strptime(dtime):
     except Exception:
         return datetime.datetime.strptime(dtime, DATETIME_PARSE)
 
-def strftime(dtime):
+def strftime(dtime, format_str=DATETIME_FMT):
     if dtime.utcoffset() != datetime.timedelta(0):
         raise Exception("datetime must be pegged at UTC tzoneinfo")
-    return dtime.strftime(DATETIME_FMT)
+    return dtime.strftime(format_str)
 
 def ratelimit(limit, every):
     def limitdecorator(func):
